@@ -19,7 +19,7 @@
 #define KSERVICETEST_H
 
 #include <QAtomicInt>
-#include <QtCore/QObject>
+#include <QObject>
 
 class KServiceTest : public QObject
 {
@@ -31,11 +31,15 @@ private Q_SLOTS:
     void testKPluginMetaData();
     void cleanupTestCase();
     void testByName();
+    void testConstructorFullPath();
+    void testConstructorKDesktopFileFullPath();
+    void testConstructorKDesktopFile();
     void testProperty();
     void testAllServiceTypes();
     void testAllServices();
     void testServiceTypeTraderForReadOnlyPart();
     void testTraderConstraints();
+    void testSubseqConstraints();
     void testHasServiceType1();
     void testHasServiceType2();
     void testWriteServiceTypeProfile();
@@ -45,16 +49,17 @@ private Q_SLOTS:
     void testByStorageId();
     void testActionsAndDataStream();
     void testServiceGroups();
-    void testKSycocaUpdate();
+    void testDeletingService();
     void testReaderThreads();
     void testThreads();
     void testOperatorKPluginName();
     void testKPluginInfoQuery();
     void testCompleteBaseName();
     void testEntryPathToName();
+    void testTraderQueryMustRebuildSycoca();
 
 private:
-    void createFakeService();
+    void createFakeService(const QString &filenameSuffix, const QString &serviceType);
     void runKBuildSycoca(bool noincremental = false);
 
     QString m_firstOffer;
